@@ -93,9 +93,9 @@
 /* old LKM code */
 #define LKM_DISPATCH(lkmtp, versioning, cmd, att, det, stat) \
 	DISPATCH(lkmtp, cmd, ver, att, det, stat)
-#define LKMLASTARG(x)	x
+#define LKMLASTARG(x,y)	,y
 #else
-#define LKMLASTARG(x)	/* nothing */
+#define LKMLASTARG(x,y)	/* nothing */
 #endif
 
 #define FILECODE "F(300)"
@@ -126,7 +126,7 @@
 #ifndef _LKM
 void vmmonattach(int);
 #else
-int vmmon_lkmentry(struct lkm_table *, int LKMLASTARG((, int)) );
+int vmmon_lkmentry(struct lkm_table *, int LKMLASTARG(0, int) );
 static int vmmon_handle(struct lkm_table *, int);
 #endif /* _LKM */
 
@@ -168,7 +168,7 @@ MOD_DEV("vmmon", LM_DT_CHAR, -1, &vmmon_cdevsw)
 #endif
 
 int
-vmmon_lkmentry(struct lkm_table *lkmtp, int cmd LKMLASTARG((, int ver)) )
+vmmon_lkmentry(struct lkm_table *lkmtp, int cmd LKMLASTARG(0, int ver) )
 {
 	LKM_DISPATCH(lkmtp, NULL, cmd, vmmon_handle, vmmon_handle, vmmon_handle)
 }
