@@ -114,9 +114,9 @@ static int ether_ioctl(struct ifnet *, u_long, caddr_t);
 /* old LKM code */
 #define LKM_DISPATCH(lkmtp, versioning, cmd, att, det, stat) \
 	DISPATCH(lkmtp, cmd, ver, att, det, stat)
-#define LKMLASTARG(x)	x
+#define LKMLASTARG(x,y)	,y
 #else
-#define LKMLASTARG(x)	/* nothing */
+#define LKMLASTARG(x,y)	/* nothing */
 #endif
 extern struct vm_map *kernel_map;
 
@@ -125,7 +125,7 @@ extern struct vm_map *kernel_map;
 #ifndef _LKM
 void vmnetattach(int);
 #else
-int vmnet_lkmentry(struct lkm_table *, int LKMLASTARG((, int)) );
+int vmnet_lkmentry(struct lkm_table *, int LKMLASTARG(0, int) );
 #endif
 
 static int hub_open(dev_t dev, int oflags, int devtype, struct ENTRYARG *);
@@ -202,7 +202,7 @@ vmnetattach(int ndev)
 
 #else /* _LKM */
 int
-vmnet_lkmentry(struct lkm_table *lkmtp, int cmd LKMLASTARG((, int ver)) )
+vmnet_lkmentry(struct lkm_table *lkmtp, int cmd LKMLASTARG(0, int ver) )
 {
 	LKM_DISPATCH(lkmtp, NULL, cmd, hub_handle, hub_handle, hub_handle)
 }
